# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetFeatureEngineeringKafkaConfigResult',
    'AwaitableGetFeatureEngineeringKafkaConfigResult',
    'get_feature_engineering_kafka_config',
    'get_feature_engineering_kafka_config_output',
]

@pulumi.output_type
class GetFeatureEngineeringKafkaConfigResult:
    """
    A collection of values returned by getFeatureEngineeringKafkaConfig.
    """
    def __init__(__self__, auth_config=None, bootstrap_servers=None, extra_options=None, id=None, key_schema=None, name=None, subscription_mode=None, value_schema=None):
        if auth_config and not isinstance(auth_config, dict):
            raise TypeError("Expected argument 'auth_config' to be a dict")
        pulumi.set(__self__, "auth_config", auth_config)
        if bootstrap_servers and not isinstance(bootstrap_servers, str):
            raise TypeError("Expected argument 'bootstrap_servers' to be a str")
        pulumi.set(__self__, "bootstrap_servers", bootstrap_servers)
        if extra_options and not isinstance(extra_options, dict):
            raise TypeError("Expected argument 'extra_options' to be a dict")
        pulumi.set(__self__, "extra_options", extra_options)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_schema and not isinstance(key_schema, dict):
            raise TypeError("Expected argument 'key_schema' to be a dict")
        pulumi.set(__self__, "key_schema", key_schema)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if subscription_mode and not isinstance(subscription_mode, dict):
            raise TypeError("Expected argument 'subscription_mode' to be a dict")
        pulumi.set(__self__, "subscription_mode", subscription_mode)
        if value_schema and not isinstance(value_schema, dict):
            raise TypeError("Expected argument 'value_schema' to be a dict")
        pulumi.set(__self__, "value_schema", value_schema)

    @_builtins.property
    @pulumi.getter(name="authConfig")
    def auth_config(self) -> 'outputs.GetFeatureEngineeringKafkaConfigAuthConfigResult':
        """
        (AuthConfig) - Authentication configuration for connection to topics
        """
        return pulumi.get(self, "auth_config")

    @_builtins.property
    @pulumi.getter(name="bootstrapServers")
    def bootstrap_servers(self) -> _builtins.str:
        """
        (string) - A comma-separated list of host/port pairs pointing to Kafka cluster
        """
        return pulumi.get(self, "bootstrap_servers")

    @_builtins.property
    @pulumi.getter(name="extraOptions")
    def extra_options(self) -> Mapping[str, _builtins.str]:
        """
        (object) - Catch-all for miscellaneous options. Keys should be source options or Kafka consumer options (kafka.*)
        """
        return pulumi.get(self, "extra_options")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="keySchema")
    def key_schema(self) -> 'outputs.GetFeatureEngineeringKafkaConfigKeySchemaResult':
        """
        (SchemaConfig) - Schema configuration for extracting message keys from topics. At least one of key_schema and value_schema must be provided
        """
        return pulumi.get(self, "key_schema")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Name that uniquely identifies this Kafka config within the metastore. This will be the identifier used from the Feature object to reference these configs for a feature.
        Can be distinct from topic name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="subscriptionMode")
    def subscription_mode(self) -> 'outputs.GetFeatureEngineeringKafkaConfigSubscriptionModeResult':
        """
        (SubscriptionMode) - Options to configure which Kafka topics to pull data from
        """
        return pulumi.get(self, "subscription_mode")

    @_builtins.property
    @pulumi.getter(name="valueSchema")
    def value_schema(self) -> 'outputs.GetFeatureEngineeringKafkaConfigValueSchemaResult':
        """
        (SchemaConfig) - Schema configuration for extracting message values from topics. At least one of key_schema and value_schema must be provided
        """
        return pulumi.get(self, "value_schema")


class AwaitableGetFeatureEngineeringKafkaConfigResult(GetFeatureEngineeringKafkaConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFeatureEngineeringKafkaConfigResult(
            auth_config=self.auth_config,
            bootstrap_servers=self.bootstrap_servers,
            extra_options=self.extra_options,
            id=self.id,
            key_schema=self.key_schema,
            name=self.name,
            subscription_mode=self.subscription_mode,
            value_schema=self.value_schema)


def get_feature_engineering_kafka_config(name: Optional[_builtins.str] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFeatureEngineeringKafkaConfigResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str name: Name that uniquely identifies this Kafka config within the metastore. This will be the identifier used from the Feature object to reference these configs for a feature.
           Can be distinct from topic name
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getFeatureEngineeringKafkaConfig:getFeatureEngineeringKafkaConfig', __args__, opts=opts, typ=GetFeatureEngineeringKafkaConfigResult).value

    return AwaitableGetFeatureEngineeringKafkaConfigResult(
        auth_config=pulumi.get(__ret__, 'auth_config'),
        bootstrap_servers=pulumi.get(__ret__, 'bootstrap_servers'),
        extra_options=pulumi.get(__ret__, 'extra_options'),
        id=pulumi.get(__ret__, 'id'),
        key_schema=pulumi.get(__ret__, 'key_schema'),
        name=pulumi.get(__ret__, 'name'),
        subscription_mode=pulumi.get(__ret__, 'subscription_mode'),
        value_schema=pulumi.get(__ret__, 'value_schema'))
def get_feature_engineering_kafka_config_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFeatureEngineeringKafkaConfigResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str name: Name that uniquely identifies this Kafka config within the metastore. This will be the identifier used from the Feature object to reference these configs for a feature.
           Can be distinct from topic name
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getFeatureEngineeringKafkaConfig:getFeatureEngineeringKafkaConfig', __args__, opts=opts, typ=GetFeatureEngineeringKafkaConfigResult)
    return __ret__.apply(lambda __response__: GetFeatureEngineeringKafkaConfigResult(
        auth_config=pulumi.get(__response__, 'auth_config'),
        bootstrap_servers=pulumi.get(__response__, 'bootstrap_servers'),
        extra_options=pulumi.get(__response__, 'extra_options'),
        id=pulumi.get(__response__, 'id'),
        key_schema=pulumi.get(__response__, 'key_schema'),
        name=pulumi.get(__response__, 'name'),
        subscription_mode=pulumi.get(__response__, 'subscription_mode'),
        value_schema=pulumi.get(__response__, 'value_schema')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetShareResult',
    'AwaitableGetShareResult',
    'get_share',
    'get_share_output',
]

@pulumi.output_type
class GetShareResult:
    """
    A collection of values returned by getShare.
    """
    def __init__(__self__, comment=None, created_at=None, created_by=None, effective_owner=None, id=None, name=None, objects=None, owner=None, provider_config=None, storage_location=None, storage_root=None, updated_at=None, updated_by=None):
        if comment and not isinstance(comment, str):
            raise TypeError("Expected argument 'comment' to be a str")
        pulumi.set(__self__, "comment", comment)
        if created_at and not isinstance(created_at, int):
            raise TypeError("Expected argument 'created_at' to be a int")
        pulumi.set(__self__, "created_at", created_at)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if effective_owner and not isinstance(effective_owner, str):
            raise TypeError("Expected argument 'effective_owner' to be a str")
        pulumi.set(__self__, "effective_owner", effective_owner)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if objects and not isinstance(objects, list):
            raise TypeError("Expected argument 'objects' to be a list")
        pulumi.set(__self__, "objects", objects)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if storage_location and not isinstance(storage_location, str):
            raise TypeError("Expected argument 'storage_location' to be a str")
        pulumi.set(__self__, "storage_location", storage_location)
        if storage_root and not isinstance(storage_root, str):
            raise TypeError("Expected argument 'storage_root' to be a str")
        pulumi.set(__self__, "storage_root", storage_root)
        if updated_at and not isinstance(updated_at, int):
            raise TypeError("Expected argument 'updated_at' to be a int")
        pulumi.set(__self__, "updated_at", updated_at)
        if updated_by and not isinstance(updated_by, str):
            raise TypeError("Expected argument 'updated_by' to be a str")
        pulumi.set(__self__, "updated_by", updated_by)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[_builtins.str]:
        """
        Description about the object.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.int:
        """
        Time when the share was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        """
        The principal that created the share.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="effectiveOwner")
    def effective_owner(self) -> _builtins.str:
        return pulumi.get(self, "effective_owner")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Full name of the object being shared.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def objects(self) -> Optional[Sequence['outputs.GetShareObjectResult']]:
        """
        arrays containing details of each object in the share.
        """
        return pulumi.get(self, "objects")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetShareProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> _builtins.str:
        return pulumi.get(self, "storage_location")

    @_builtins.property
    @pulumi.getter(name="storageRoot")
    def storage_root(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "storage_root")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.int:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> _builtins.str:
        return pulumi.get(self, "updated_by")


class AwaitableGetShareResult(GetShareResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetShareResult(
            comment=self.comment,
            created_at=self.created_at,
            created_by=self.created_by,
            effective_owner=self.effective_owner,
            id=self.id,
            name=self.name,
            objects=self.objects,
            owner=self.owner,
            provider_config=self.provider_config,
            storage_location=self.storage_location,
            storage_root=self.storage_root,
            updated_at=self.updated_at,
            updated_by=self.updated_by)


def get_share(comment: Optional[_builtins.str] = None,
              name: Optional[_builtins.str] = None,
              objects: Optional[Sequence[Union['GetShareObjectArgs', 'GetShareObjectArgsDict']]] = None,
              owner: Optional[_builtins.str] = None,
              provider_config: Optional[Union['GetShareProviderConfigArgs', 'GetShareProviderConfigArgsDict']] = None,
              storage_root: Optional[_builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetShareResult:
    """
    Retrieves details about a Share that were created by Pulumi or manually.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Getting details of an existing share in the metastore

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_share(name="this")
    pulumi.export("createdBy", this.created_by)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Share to create Delta Sharing shares.
    * Recipient to create Delta Sharing recipients.
    * Grants to manage Delta Sharing permissions.


    :param _builtins.str comment: Description about the object.
    :param _builtins.str name: The name of the share
    :param Sequence[Union['GetShareObjectArgs', 'GetShareObjectArgsDict']] objects: arrays containing details of each object in the share.
    :param Union['GetShareProviderConfigArgs', 'GetShareProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['comment'] = comment
    __args__['name'] = name
    __args__['objects'] = objects
    __args__['owner'] = owner
    __args__['providerConfig'] = provider_config
    __args__['storageRoot'] = storage_root
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getShare:getShare', __args__, opts=opts, typ=GetShareResult).value

    return AwaitableGetShareResult(
        comment=pulumi.get(__ret__, 'comment'),
        created_at=pulumi.get(__ret__, 'created_at'),
        created_by=pulumi.get(__ret__, 'created_by'),
        effective_owner=pulumi.get(__ret__, 'effective_owner'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        objects=pulumi.get(__ret__, 'objects'),
        owner=pulumi.get(__ret__, 'owner'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        storage_location=pulumi.get(__ret__, 'storage_location'),
        storage_root=pulumi.get(__ret__, 'storage_root'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        updated_by=pulumi.get(__ret__, 'updated_by'))
def get_share_output(comment: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     objects: Optional[pulumi.Input[Optional[Sequence[Union['GetShareObjectArgs', 'GetShareObjectArgsDict']]]]] = None,
                     owner: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     provider_config: Optional[pulumi.Input[Optional[Union['GetShareProviderConfigArgs', 'GetShareProviderConfigArgsDict']]]] = None,
                     storage_root: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetShareResult]:
    """
    Retrieves details about a Share that were created by Pulumi or manually.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Getting details of an existing share in the metastore

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_share(name="this")
    pulumi.export("createdBy", this.created_by)
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Share to create Delta Sharing shares.
    * Recipient to create Delta Sharing recipients.
    * Grants to manage Delta Sharing permissions.


    :param _builtins.str comment: Description about the object.
    :param _builtins.str name: The name of the share
    :param Sequence[Union['GetShareObjectArgs', 'GetShareObjectArgsDict']] objects: arrays containing details of each object in the share.
    :param Union['GetShareProviderConfigArgs', 'GetShareProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['comment'] = comment
    __args__['name'] = name
    __args__['objects'] = objects
    __args__['owner'] = owner
    __args__['providerConfig'] = provider_config
    __args__['storageRoot'] = storage_root
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getShare:getShare', __args__, opts=opts, typ=GetShareResult)
    return __ret__.apply(lambda __response__: GetShareResult(
        comment=pulumi.get(__response__, 'comment'),
        created_at=pulumi.get(__response__, 'created_at'),
        created_by=pulumi.get(__response__, 'created_by'),
        effective_owner=pulumi.get(__response__, 'effective_owner'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        objects=pulumi.get(__response__, 'objects'),
        owner=pulumi.get(__response__, 'owner'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        storage_location=pulumi.get(__response__, 'storage_location'),
        storage_root=pulumi.get(__response__, 'storage_root'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        updated_by=pulumi.get(__response__, 'updated_by')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetFeatureEngineeringMaterializedFeatureResult',
    'AwaitableGetFeatureEngineeringMaterializedFeatureResult',
    'get_feature_engineering_materialized_feature',
    'get_feature_engineering_materialized_feature_output',
]

@pulumi.output_type
class GetFeatureEngineeringMaterializedFeatureResult:
    """
    A collection of values returned by getFeatureEngineeringMaterializedFeature.
    """
    def __init__(__self__, cron_schedule=None, feature_name=None, id=None, last_materialization_time=None, materialized_feature_id=None, offline_store_config=None, online_store_config=None, pipeline_schedule_state=None, table_name=None):
        if cron_schedule and not isinstance(cron_schedule, str):
            raise TypeError("Expected argument 'cron_schedule' to be a str")
        pulumi.set(__self__, "cron_schedule", cron_schedule)
        if feature_name and not isinstance(feature_name, str):
            raise TypeError("Expected argument 'feature_name' to be a str")
        pulumi.set(__self__, "feature_name", feature_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_materialization_time and not isinstance(last_materialization_time, str):
            raise TypeError("Expected argument 'last_materialization_time' to be a str")
        pulumi.set(__self__, "last_materialization_time", last_materialization_time)
        if materialized_feature_id and not isinstance(materialized_feature_id, str):
            raise TypeError("Expected argument 'materialized_feature_id' to be a str")
        pulumi.set(__self__, "materialized_feature_id", materialized_feature_id)
        if offline_store_config and not isinstance(offline_store_config, dict):
            raise TypeError("Expected argument 'offline_store_config' to be a dict")
        pulumi.set(__self__, "offline_store_config", offline_store_config)
        if online_store_config and not isinstance(online_store_config, dict):
            raise TypeError("Expected argument 'online_store_config' to be a dict")
        pulumi.set(__self__, "online_store_config", online_store_config)
        if pipeline_schedule_state and not isinstance(pipeline_schedule_state, str):
            raise TypeError("Expected argument 'pipeline_schedule_state' to be a str")
        pulumi.set(__self__, "pipeline_schedule_state", pipeline_schedule_state)
        if table_name and not isinstance(table_name, str):
            raise TypeError("Expected argument 'table_name' to be a str")
        pulumi.set(__self__, "table_name", table_name)

    @_builtins.property
    @pulumi.getter(name="cronSchedule")
    def cron_schedule(self) -> _builtins.str:
        """
        (string) - The quartz cron expression that defines the schedule of the materialization pipeline. The schedule is evaluated in the UTC timezone
        """
        return pulumi.get(self, "cron_schedule")

    @_builtins.property
    @pulumi.getter(name="featureName")
    def feature_name(self) -> _builtins.str:
        """
        (string) - The full name of the feature in Unity Catalog
        """
        return pulumi.get(self, "feature_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastMaterializationTime")
    def last_materialization_time(self) -> _builtins.str:
        """
        (string) - The timestamp when the pipeline last ran and updated the materialized feature values.
        If the pipeline has not run yet, this field will be null
        """
        return pulumi.get(self, "last_materialization_time")

    @_builtins.property
    @pulumi.getter(name="materializedFeatureId")
    def materialized_feature_id(self) -> _builtins.str:
        """
        (string) - Unique identifier for the materialized feature
        """
        return pulumi.get(self, "materialized_feature_id")

    @_builtins.property
    @pulumi.getter(name="offlineStoreConfig")
    def offline_store_config(self) -> 'outputs.GetFeatureEngineeringMaterializedFeatureOfflineStoreConfigResult':
        """
        (OfflineStoreConfig)
        """
        return pulumi.get(self, "offline_store_config")

    @_builtins.property
    @pulumi.getter(name="onlineStoreConfig")
    def online_store_config(self) -> 'outputs.GetFeatureEngineeringMaterializedFeatureOnlineStoreConfigResult':
        """
        (OnlineStoreConfig)
        """
        return pulumi.get(self, "online_store_config")

    @_builtins.property
    @pulumi.getter(name="pipelineScheduleState")
    def pipeline_schedule_state(self) -> _builtins.str:
        """
        (string) - The schedule state of the materialization pipeline. Possible values are: `ACTIVE`, `PAUSED`, `SNAPSHOT`
        """
        return pulumi.get(self, "pipeline_schedule_state")

    @_builtins.property
    @pulumi.getter(name="tableName")
    def table_name(self) -> _builtins.str:
        """
        (string) - The fully qualified Unity Catalog path to the table containing the materialized feature (Delta table or Lakebase table). Output only
        """
        return pulumi.get(self, "table_name")


class AwaitableGetFeatureEngineeringMaterializedFeatureResult(GetFeatureEngineeringMaterializedFeatureResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFeatureEngineeringMaterializedFeatureResult(
            cron_schedule=self.cron_schedule,
            feature_name=self.feature_name,
            id=self.id,
            last_materialization_time=self.last_materialization_time,
            materialized_feature_id=self.materialized_feature_id,
            offline_store_config=self.offline_store_config,
            online_store_config=self.online_store_config,
            pipeline_schedule_state=self.pipeline_schedule_state,
            table_name=self.table_name)


def get_feature_engineering_materialized_feature(materialized_feature_id: Optional[_builtins.str] = None,
                                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFeatureEngineeringMaterializedFeatureResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str materialized_feature_id: Unique identifier for the materialized feature
    """
    __args__ = dict()
    __args__['materializedFeatureId'] = materialized_feature_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getFeatureEngineeringMaterializedFeature:getFeatureEngineeringMaterializedFeature', __args__, opts=opts, typ=GetFeatureEngineeringMaterializedFeatureResult).value

    return AwaitableGetFeatureEngineeringMaterializedFeatureResult(
        cron_schedule=pulumi.get(__ret__, 'cron_schedule'),
        feature_name=pulumi.get(__ret__, 'feature_name'),
        id=pulumi.get(__ret__, 'id'),
        last_materialization_time=pulumi.get(__ret__, 'last_materialization_time'),
        materialized_feature_id=pulumi.get(__ret__, 'materialized_feature_id'),
        offline_store_config=pulumi.get(__ret__, 'offline_store_config'),
        online_store_config=pulumi.get(__ret__, 'online_store_config'),
        pipeline_schedule_state=pulumi.get(__ret__, 'pipeline_schedule_state'),
        table_name=pulumi.get(__ret__, 'table_name'))
def get_feature_engineering_materialized_feature_output(materialized_feature_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFeatureEngineeringMaterializedFeatureResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str materialized_feature_id: Unique identifier for the materialized feature
    """
    __args__ = dict()
    __args__['materializedFeatureId'] = materialized_feature_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getFeatureEngineeringMaterializedFeature:getFeatureEngineeringMaterializedFeature', __args__, opts=opts, typ=GetFeatureEngineeringMaterializedFeatureResult)
    return __ret__.apply(lambda __response__: GetFeatureEngineeringMaterializedFeatureResult(
        cron_schedule=pulumi.get(__response__, 'cron_schedule'),
        feature_name=pulumi.get(__response__, 'feature_name'),
        id=pulumi.get(__response__, 'id'),
        last_materialization_time=pulumi.get(__response__, 'last_materialization_time'),
        materialized_feature_id=pulumi.get(__response__, 'materialized_feature_id'),
        offline_store_config=pulumi.get(__response__, 'offline_store_config'),
        online_store_config=pulumi.get(__response__, 'online_store_config'),
        pipeline_schedule_state=pulumi.get(__response__, 'pipeline_schedule_state'),
        table_name=pulumi.get(__response__, 'table_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ServicePrincipalSecretArgs', 'ServicePrincipalSecret']

@pulumi.input_type
class ServicePrincipalSecretArgs:
    def __init__(__self__, *,
                 service_principal_id: pulumi.Input[_builtins.str],
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 expire_time: Optional[pulumi.Input[_builtins.str]] = None,
                 lifetime: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 time_rotating: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ServicePrincipalSecret resource.
        :param pulumi.Input[_builtins.str] service_principal_id: SCIM ID of the ServicePrincipal (not application ID).
        :param pulumi.Input[_builtins.str] create_time: UTC time when the secret was created.
        :param pulumi.Input[_builtins.str] expire_time: UTC time when the secret will expire. If the field is not present, the secret does not expire.
        :param pulumi.Input[_builtins.str] lifetime: The lifetime of the secret in seconds formatted as `NNNNs`. If this parameter is not provided, the secret will have a default lifetime of 730 days (`63072000s`).  Expiration of secret will lead to generation of new secret.
        :param pulumi.Input[_builtins.str] secret: **Sensitive** Generated secret for the service principal.
        :param pulumi.Input[_builtins.str] secret_hash: Secret Hash.
        :param pulumi.Input[_builtins.str] status: Status of the secret (i.e., `ACTIVE` - see [REST API docs for full list](https://docs.databricks.com/api/account/serviceprincipalsecrets/list#secrets-status)).
        :param pulumi.Input[_builtins.str] time_rotating: Changing this argument forces recreation of the secret.
        :param pulumi.Input[_builtins.str] update_time: UTC time when the secret was updated.
        """
        pulumi.set(__self__, "service_principal_id", service_principal_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if expire_time is not None:
            pulumi.set(__self__, "expire_time", expire_time)
        if lifetime is not None:
            pulumi.set(__self__, "lifetime", lifetime)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if secret_hash is not None:
            pulumi.set(__self__, "secret_hash", secret_hash)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if time_rotating is not None:
            pulumi.set(__self__, "time_rotating", time_rotating)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> pulumi.Input[_builtins.str]:
        """
        SCIM ID of the ServicePrincipal (not application ID).
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_principal_id", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UTC time when the secret was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UTC time when the secret will expire. If the field is not present, the secret does not expire.
        """
        return pulumi.get(self, "expire_time")

    @expire_time.setter
    def expire_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expire_time", value)

    @_builtins.property
    @pulumi.getter
    def lifetime(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The lifetime of the secret in seconds formatted as `NNNNs`. If this parameter is not provided, the secret will have a default lifetime of 730 days (`63072000s`).  Expiration of secret will lead to generation of new secret.
        """
        return pulumi.get(self, "lifetime")

    @lifetime.setter
    def lifetime(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lifetime", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **Sensitive** Generated secret for the service principal.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret", value)

    @_builtins.property
    @pulumi.getter(name="secretHash")
    def secret_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secret Hash.
        """
        return pulumi.get(self, "secret_hash")

    @secret_hash.setter
    def secret_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_hash", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the secret (i.e., `ACTIVE` - see [REST API docs for full list](https://docs.databricks.com/api/account/serviceprincipalsecrets/list#secrets-status)).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="timeRotating")
    def time_rotating(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Changing this argument forces recreation of the secret.
        """
        return pulumi.get(self, "time_rotating")

    @time_rotating.setter
    def time_rotating(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "time_rotating", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UTC time when the secret was updated.
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.input_type
class _ServicePrincipalSecretState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 expire_time: Optional[pulumi.Input[_builtins.str]] = None,
                 lifetime: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 time_rotating: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServicePrincipalSecret resources.
        :param pulumi.Input[_builtins.str] create_time: UTC time when the secret was created.
        :param pulumi.Input[_builtins.str] expire_time: UTC time when the secret will expire. If the field is not present, the secret does not expire.
        :param pulumi.Input[_builtins.str] lifetime: The lifetime of the secret in seconds formatted as `NNNNs`. If this parameter is not provided, the secret will have a default lifetime of 730 days (`63072000s`).  Expiration of secret will lead to generation of new secret.
        :param pulumi.Input[_builtins.str] secret: **Sensitive** Generated secret for the service principal.
        :param pulumi.Input[_builtins.str] secret_hash: Secret Hash.
        :param pulumi.Input[_builtins.str] service_principal_id: SCIM ID of the ServicePrincipal (not application ID).
        :param pulumi.Input[_builtins.str] status: Status of the secret (i.e., `ACTIVE` - see [REST API docs for full list](https://docs.databricks.com/api/account/serviceprincipalsecrets/list#secrets-status)).
        :param pulumi.Input[_builtins.str] time_rotating: Changing this argument forces recreation of the secret.
        :param pulumi.Input[_builtins.str] update_time: UTC time when the secret was updated.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if expire_time is not None:
            pulumi.set(__self__, "expire_time", expire_time)
        if lifetime is not None:
            pulumi.set(__self__, "lifetime", lifetime)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if secret_hash is not None:
            pulumi.set(__self__, "secret_hash", secret_hash)
        if service_principal_id is not None:
            pulumi.set(__self__, "service_principal_id", service_principal_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if time_rotating is not None:
            pulumi.set(__self__, "time_rotating", time_rotating)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UTC time when the secret was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UTC time when the secret will expire. If the field is not present, the secret does not expire.
        """
        return pulumi.get(self, "expire_time")

    @expire_time.setter
    def expire_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expire_time", value)

    @_builtins.property
    @pulumi.getter
    def lifetime(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The lifetime of the secret in seconds formatted as `NNNNs`. If this parameter is not provided, the secret will have a default lifetime of 730 days (`63072000s`).  Expiration of secret will lead to generation of new secret.
        """
        return pulumi.get(self, "lifetime")

    @lifetime.setter
    def lifetime(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lifetime", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **Sensitive** Generated secret for the service principal.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret", value)

    @_builtins.property
    @pulumi.getter(name="secretHash")
    def secret_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secret Hash.
        """
        return pulumi.get(self, "secret_hash")

    @secret_hash.setter
    def secret_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_hash", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        SCIM ID of the ServicePrincipal (not application ID).
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_principal_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the secret (i.e., `ACTIVE` - see [REST API docs for full list](https://docs.databricks.com/api/account/serviceprincipalsecrets/list#secrets-status)).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="timeRotating")
    def time_rotating(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Changing this argument forces recreation of the secret.
        """
        return pulumi.get(self, "time_rotating")

    @time_rotating.setter
    def time_rotating(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "time_rotating", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        UTC time when the secret was updated.
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("databricks:index/servicePrincipalSecret:ServicePrincipalSecret")
class ServicePrincipalSecret(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 expire_time: Optional[pulumi.Input[_builtins.str]] = None,
                 lifetime: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 time_rotating: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        With this resource you can create a secret for a given [Service Principals](https://docs.databricks.com/administration-guide/users-groups/service-principals.html).

        > This resource can only be used with an account-level or workspace-level provider!

        This secret can be used to configure the Databricks Pulumi Provider to authenticate with the service principal. See Authenticating with service principal.

        Additionally, the secret can be used to request OAuth tokens for the service principal, which can be used to authenticate to Databricks REST APIs. See [Authentication using OAuth tokens for service principals](https://docs.databricks.com/dev-tools/authentication-oauth.html).

        ## Example Usage

        Create service principal secret

        ```python
        import pulumi
        import pulumi_databricks as databricks

        terraform_sp = databricks.ServicePrincipalSecret("terraform_sp", service_principal_id=this["id"])
        ```

        A secret can be automatically rotated by taking a dependency on the `time_rotating` resource:

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumiverse_time as time

        this = time.Rotating("this", rotation_days=30)
        terraform_sp = databricks.ServicePrincipalSecret("terraform_sp",
            service_principal_id=this_databricks_service_principal["id"],
            time_rotating=this.rfc3339.apply(lambda rfc3339: f"Pulumi (created: {rfc3339})"))
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * ServicePrincipal to manage [Service Principals](https://docs.databricks.com/administration-guide/users-groups/service-principals.html) in Databricks

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: UTC time when the secret was created.
        :param pulumi.Input[_builtins.str] expire_time: UTC time when the secret will expire. If the field is not present, the secret does not expire.
        :param pulumi.Input[_builtins.str] lifetime: The lifetime of the secret in seconds formatted as `NNNNs`. If this parameter is not provided, the secret will have a default lifetime of 730 days (`63072000s`).  Expiration of secret will lead to generation of new secret.
        :param pulumi.Input[_builtins.str] secret: **Sensitive** Generated secret for the service principal.
        :param pulumi.Input[_builtins.str] secret_hash: Secret Hash.
        :param pulumi.Input[_builtins.str] service_principal_id: SCIM ID of the ServicePrincipal (not application ID).
        :param pulumi.Input[_builtins.str] status: Status of the secret (i.e., `ACTIVE` - see [REST API docs for full list](https://docs.databricks.com/api/account/serviceprincipalsecrets/list#secrets-status)).
        :param pulumi.Input[_builtins.str] time_rotating: Changing this argument forces recreation of the secret.
        :param pulumi.Input[_builtins.str] update_time: UTC time when the secret was updated.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServicePrincipalSecretArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        With this resource you can create a secret for a given [Service Principals](https://docs.databricks.com/administration-guide/users-groups/service-principals.html).

        > This resource can only be used with an account-level or workspace-level provider!

        This secret can be used to configure the Databricks Pulumi Provider to authenticate with the service principal. See Authenticating with service principal.

        Additionally, the secret can be used to request OAuth tokens for the service principal, which can be used to authenticate to Databricks REST APIs. See [Authentication using OAuth tokens for service principals](https://docs.databricks.com/dev-tools/authentication-oauth.html).

        ## Example Usage

        Create service principal secret

        ```python
        import pulumi
        import pulumi_databricks as databricks

        terraform_sp = databricks.ServicePrincipalSecret("terraform_sp", service_principal_id=this["id"])
        ```

        A secret can be automatically rotated by taking a dependency on the `time_rotating` resource:

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumiverse_time as time

        this = time.Rotating("this", rotation_days=30)
        terraform_sp = databricks.ServicePrincipalSecret("terraform_sp",
            service_principal_id=this_databricks_service_principal["id"],
            time_rotating=this.rfc3339.apply(lambda rfc3339: f"Pulumi (created: {rfc3339})"))
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * ServicePrincipal to manage [Service Principals](https://docs.databricks.com/administration-guide/users-groups/service-principals.html) in Databricks

        :param str resource_name: The name of the resource.
        :param ServicePrincipalSecretArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServicePrincipalSecretArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 expire_time: Optional[pulumi.Input[_builtins.str]] = None,
                 lifetime: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 time_rotating: Optional[pulumi.Input[_builtins.str]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServicePrincipalSecretArgs.__new__(ServicePrincipalSecretArgs)

            __props__.__dict__["create_time"] = create_time
            __props__.__dict__["expire_time"] = expire_time
            __props__.__dict__["lifetime"] = lifetime
            __props__.__dict__["secret"] = None if secret is None else pulumi.Output.secret(secret)
            __props__.__dict__["secret_hash"] = secret_hash
            if service_principal_id is None and not opts.urn:
                raise TypeError("Missing required property 'service_principal_id'")
            __props__.__dict__["service_principal_id"] = service_principal_id
            __props__.__dict__["status"] = status
            __props__.__dict__["time_rotating"] = time_rotating
            __props__.__dict__["update_time"] = update_time
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ServicePrincipalSecret, __self__).__init__(
            'databricks:index/servicePrincipalSecret:ServicePrincipalSecret',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            expire_time: Optional[pulumi.Input[_builtins.str]] = None,
            lifetime: Optional[pulumi.Input[_builtins.str]] = None,
            secret: Optional[pulumi.Input[_builtins.str]] = None,
            secret_hash: Optional[pulumi.Input[_builtins.str]] = None,
            service_principal_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            time_rotating: Optional[pulumi.Input[_builtins.str]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None) -> 'ServicePrincipalSecret':
        """
        Get an existing ServicePrincipalSecret resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: UTC time when the secret was created.
        :param pulumi.Input[_builtins.str] expire_time: UTC time when the secret will expire. If the field is not present, the secret does not expire.
        :param pulumi.Input[_builtins.str] lifetime: The lifetime of the secret in seconds formatted as `NNNNs`. If this parameter is not provided, the secret will have a default lifetime of 730 days (`63072000s`).  Expiration of secret will lead to generation of new secret.
        :param pulumi.Input[_builtins.str] secret: **Sensitive** Generated secret for the service principal.
        :param pulumi.Input[_builtins.str] secret_hash: Secret Hash.
        :param pulumi.Input[_builtins.str] service_principal_id: SCIM ID of the ServicePrincipal (not application ID).
        :param pulumi.Input[_builtins.str] status: Status of the secret (i.e., `ACTIVE` - see [REST API docs for full list](https://docs.databricks.com/api/account/serviceprincipalsecrets/list#secrets-status)).
        :param pulumi.Input[_builtins.str] time_rotating: Changing this argument forces recreation of the secret.
        :param pulumi.Input[_builtins.str] update_time: UTC time when the secret was updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServicePrincipalSecretState.__new__(_ServicePrincipalSecretState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["expire_time"] = expire_time
        __props__.__dict__["lifetime"] = lifetime
        __props__.__dict__["secret"] = secret
        __props__.__dict__["secret_hash"] = secret_hash
        __props__.__dict__["service_principal_id"] = service_principal_id
        __props__.__dict__["status"] = status
        __props__.__dict__["time_rotating"] = time_rotating
        __props__.__dict__["update_time"] = update_time
        return ServicePrincipalSecret(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        UTC time when the secret was created.
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> pulumi.Output[_builtins.str]:
        """
        UTC time when the secret will expire. If the field is not present, the secret does not expire.
        """
        return pulumi.get(self, "expire_time")

    @_builtins.property
    @pulumi.getter
    def lifetime(self) -> pulumi.Output[_builtins.str]:
        """
        The lifetime of the secret in seconds formatted as `NNNNs`. If this parameter is not provided, the secret will have a default lifetime of 730 days (`63072000s`).  Expiration of secret will lead to generation of new secret.
        """
        return pulumi.get(self, "lifetime")

    @_builtins.property
    @pulumi.getter
    def secret(self) -> pulumi.Output[_builtins.str]:
        """
        **Sensitive** Generated secret for the service principal.
        """
        return pulumi.get(self, "secret")

    @_builtins.property
    @pulumi.getter(name="secretHash")
    def secret_hash(self) -> pulumi.Output[_builtins.str]:
        """
        Secret Hash.
        """
        return pulumi.get(self, "secret_hash")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> pulumi.Output[_builtins.str]:
        """
        SCIM ID of the ServicePrincipal (not application ID).
        """
        return pulumi.get(self, "service_principal_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Status of the secret (i.e., `ACTIVE` - see [REST API docs for full list](https://docs.databricks.com/api/account/serviceprincipalsecrets/list#secrets-status)).
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="timeRotating")
    def time_rotating(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Changing this argument forces recreation of the secret.
        """
        return pulumi.get(self, "time_rotating")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        UTC time when the secret was updated.
        """
        return pulumi.get(self, "update_time")

